@@ -21,7 +21,7 @@ Sample usage:
 			frob = frob_rsp_et.findtext('frob')
 	
 	# get the desktop authentication url
-	auth_url = api.get_auth_url(frob, 'write')
+	auth_url = api.get_authurl('write', frob=frob)
 
 	# ask the user to authorize your app now using that url
 	print "auth me:  %s" % (auth_url,)
@@ -54,7 +54,7 @@ Sample usage:
 """
 
 __author__ = "Gilad Raphaelli"
-__version__ = "0.4"
+__version__ = "0.4.1"
 
 import md5,mimetypes,urllib,urllib2
 import warnings
@@ -160,16 +160,30 @@ class API:
 
 		return urllib2.urlopen(request)
 
-	def get_auth_url(self, frob, perms):
-		""" Given a frob obtained via a 'flickr.auth.getFrob' and perms (currently read, write, or delete) return a url for client api authorization """
+	def get_authurl(self, perms, **kwargs):
+		""" Get a client authentication url for web-based and non-web based clients
+		
+		New in 0.4.1, use this method instead of get_auth_url """
+
 		args = {
 			'perms': perms,
 			'api_key': self.key,
-			'frob': frob
 		}
-		args['api_sig'] = sign_args(self.secret, args)
 
-		return "http://flickr.com/services/auth/?%s" % (urllib.urlencode(args),)
+		kwargs.update(args)
+
+		kwargs['api_sig'] = sign_args(self.secret, kwargs)
+
+		return "http://flickr.com/services/auth/?%s" % (urllib.urlencode(kwargs),)
+		
+	def get_auth_url(self, frob, perms):
+		""" Given a frob obtained via a 'flickr.auth.getFrob' and perms
+		(currently read, write, or delete) return a url for desktop client api
+		authentication
+
+		Deprecated in 0.4.1, use get_authurl for new applications """
+
+		return get_authurl(perms, frob=frob)
 
 	def _sign_args(self, args):
 		return sign_args(self.secret, args)
